@@ -25,20 +25,40 @@ void KReplaceTest::enterLoop()
     eventLoop.exec(QEventLoop::ExcludeUserInputEvents);
 }
 
+KReplaceTest::KReplaceTest(const QStringList &text, const QString &buttonName)
+    : QObject(nullptr)
+    , m_text(text)
+    , m_replace(nullptr)
+    , m_buttonName(buttonName)
+{
+}
+
+KReplaceTest::~KReplaceTest()
+{
+}
+
 void KReplaceTest::replace(const QString &pattern, const QString &replacement, long options)
 {
     m_needEventLoop = false;
     // This creates a replace-next-prompt dialog if needed.
-    delete m_replace;
-    m_replace = new KReplace(pattern, replacement, options);
+    m_replace.reset(new KReplace(pattern, replacement, options));
+
+    // Connect highlight (or textFound) signal to code which handles highlighting of found text.
+#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 81)
+    connect(m_replace.get(), qOverload<const QString &, int, int>(&KFind::highlight), this, &KReplaceTest::slotHighlight);
+#else
+    connect(m_replace.get(), &KFind::textFound, this, &KReplaceTest::slotHighlight);
+#endif
 
-    // Connect highlight signal to code which handles highlighting
-    // of found text.
-    connect(m_replace, SIGNAL(highlight(QString, int, int)), this, SLOT(slotHighlight(QString, int, int)));
     // Connect findNext signal - called when pressing the button in the dialog
-    connect(m_replace, &KFind::findNext, this, &KReplaceTest::slotReplaceNext);
+    connect(m_replace.get(), &KFind::findNext, this, &KReplaceTest::slotReplaceNext);
+
     // Connect replace signal - called when doing a replacement
-    connect(m_replace, SIGNAL(replace(QString, int, int, int)), this, SLOT(slotReplace(QString, int, int, int)));
+#if KTEXTWIDGETS_ENABLE_DEPRECATED_SINCE(5, 83)
+    connect(m_replace.get(), qOverload<const QString &, int, int, int>(&KReplace::replace), this, &KReplaceTest::slotReplace);
+#else
+    connect(m_replace.get(), &KReplace::textReplaced, this, &KReplaceTest::slotReplace);
+#endif
 
     // Go to initial position
     if ((options & KFind::FromCursor) == 0) {
@@ -69,11 +89,14 @@ void KReplaceTest::slotHighlight(const QString &str, int matchingIndex, int matc
     // so slotReplaceNext never returns)
     if (m_replace->options() & KReplaceDialog::PromptOnReplace) {
         QDialog *dlg = m_replace->replaceNextDialog(false);
-        disconnect(dlg, SIGNAL(finished(int)), m_replace, nullptr); // hack to avoid _k_slotDialogClosed being called
+        disconnect(dlg, &QDialog::finished, m_replace.get(), nullptr); // hack to avoid slotDialogClosed being called
         dlg->hide();
 
         QPushButton *button = dlg->findChild<QPushButton *>(m_buttonName);
-        QMetaObject::invokeMethod(button, "click", Qt::QueuedConnection);
+        auto clickFunc = [button]() {
+            button->click();
+        };
+        QMetaObject::invokeMethod(button, clickFunc, Qt::QueuedConnection);
 
         m_needEventLoop = true;
     }
@@ -362,3 +385,5 @@ int main(int argc, char **argv)
     // return app.exec();
     return 0;
 }
+
+#include "moc_kreplacetest.cpp"
