@@ -1,21 +1,9 @@
 /*
-    Copyright (C) 2001, S.R.Haque <srhaque@iee.org>.
-    Copyright (C) 2002, David Faure <david@mandrakesoft.com>
     This file is part of the KDE project
+    SPDX-FileCopyrightText: 2001 S.R. Haque <srhaque@iee.org>.
+    SPDX-FileCopyrightText: 2002 David Faure <david@mandrakesoft.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2, as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LGPL-2.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KREPLACEDIALOG_H
@@ -54,19 +42,17 @@ class KReplaceDialogPrivate;
  *
  * \image html kreplacedialog.png "KReplaceDialog Widget"
  */
-class KTEXTWIDGETS_EXPORT KReplaceDialog:
-    public KFindDialog
+class KTEXTWIDGETS_EXPORT KReplaceDialog : public KFindDialog
 {
     Q_OBJECT
 
 public:
-
     /// Options.
 
     enum Options {
         /// Should the user be prompted before the replace operation?
         PromptOnReplace = 256,
-        BackReference = 512
+        BackReference = 512,
     };
 
     /**
@@ -80,7 +66,8 @@ public:
      *        replace with
      * @param hasSelection Whether a selection exists
      */
-    explicit KReplaceDialog(QWidget *parent = nullptr, long options = 0,
+    explicit KReplaceDialog(QWidget *parent = nullptr,
+                            long options = 0,
                             const QStringList &findStrings = QStringList(),
                             const QStringList &replaceStrings = QStringList(),
                             bool hasSelection = true);
@@ -88,7 +75,7 @@ public:
     /**
      * Destructor.
      */
-    virtual ~KReplaceDialog();
+    ~KReplaceDialog() override;
 
     /**
      * Provide the list of @p strings to be displayed as the history
@@ -136,13 +123,17 @@ public:
     QWidget *replaceExtension() const;
 
 protected:
-    void showEvent(QShowEvent *) Q_DECL_OVERRIDE;
+    void showEvent(QShowEvent *) override;
 
 private:
-
-    KReplaceDialogPrivate *const d;
-
-    Q_PRIVATE_SLOT(d, void _k_slotOk())
+    Q_DECLARE_PRIVATE_D(KFindDialog::d, KReplaceDialog)
+#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 79)
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_CLANG("-Wunused-private-field")
+    // Unused, kept for ABI compatibility
+    const void *__ktextwidgets_d_do_not_use;
+    QT_WARNING_POP
+#endif
 };
 
 #endif // KREPLACEDIALOG_H
